EstimateSigActivity: Estimate signature activity

View source: R/source.R

EstimateSigActivityR Documentation

Estimate signature activity

Description

Estimate signature activities from a mutation-count matrix, a sample-level panel-context matrix, and a catalog signature-profile matrix.

Usage

 EstimateSigActivity(V, L, W, n.start=50, iter.max=5000, eps=1e-5)

Arguments

V

Mutation-count matrix or data frame with samples in columns

L

Sample-level panel-context matrix or data frame with samples in columns, see GenerateLMatrix

W

Catalog signature-profile matrix or data frame with signatures in columns

n.start

Number of initializations. The default is 50.

iter.max

Maximum number of iterations in the EM algorithm. The default is 5000.

eps

Stopping tolerance in the EM algorithm. The default is 1e-5.

Details

The sample-level panel-context matrix L and mutation-count matrix V are of size P (the mutation context) by N (the sample size). The catalog signature-profile matrix W has dimension P by K (the number of signatures). For single base substitutions (SBS), P is 96. For the objects V, L, and W, we must have dim(V) = dim(L) and ncol(W) = K, where K is the number of signatures. The input matrices must contain numeric, finite and non-negative values, and V must contain integer-like mutation counts. When row names and column names are present, EstimateSigActivity() checks that V, L and W contain matched mutation contexts and matched sample IDs. If the same names are present in a different order, L and W are reordered to match V. If one object has names on an axis used for alignment and the paired object does not, or if the named entries differ between matrices, the function stops with an informative error. Users can run ValidateSATSInputs directly to check and align inputs before calling this function. EstimateSigActivity() uses an EM algorithm to estimate the signature activity matrix. The arguments n.start, iter.max and eps control the number of random starts, maximum number of EM iterations and stopping tolerance, respectively. Because convergence to a local optimum can occur, the default uses multiple initial values (n.start = 50). For each initial value, the default maximum number of EM iterations is iter.max = 5000, and the stopping tolerance is eps = 1e-5. For the catalog signature profile matrix W, reference SBS TMB signature profiles in data(SimData) can be used.

Value

A list containing the estimated activity matrix H, the log-likelihood loglike, and the logical value converged.

Author(s)

Donghyuk Lee <dhyuklee@pusan.ac.kr> and Bin Zhu <bin.zhu@nih.gov>

See Also

CalculateSignatureBurdens, ValidateSATSInputs

Examples

    data(SimData, package="SATS")
  
    EstimateSigActivity(SimData$V, SimData$L, SimData$TrueW_TMB)
   
  # For more detailed usage, please refer to README and the user manual
  # in https://github.com/binzhulab/SATS/tree/main.

SATS documentation built on Sept. 16, 2026, 1:06 a.m.