SATS-package: SATS (Signature Analyzer for Targeted Sequencing)

SATS-packageR Documentation

SATS (Signature Analyzer for Targeted Sequencing)

Description

This package performs mutational signature analysis for tumors profiled by targeted sequencing. Unlike the canonical analysis of mutational signatures, SATS factorizes the mutation counts matrix into a panel context matrix (measuring mutation opportunities per million base pairs for each tumor), a signature profile matrix, and a signature activity matrix. SATS also calculates the expected number of mutations attributed by a signature, namely signature burden, for each tumor profiled by targeted sequencing.

Details

This package includes a novel algorithm, SATS, to perform mutational signature analysis for targeted sequencing data. The algorithm first applies the signeR algorithm to extract profiles of de novo mutational signatures by appropriately adjusting for various panel sizes. Next, the profiles of identified de novo mutational signatures are mapped to the profiles of catalog signatures of tumor mutation burden (TMB), measured as the number of mutations per million base pairs, using penalized non-negative least squares. Then, given the panel sizes and profiles of mapped TMB catalog signatures, signature activities are estimated for all samples simultaneously through the Expectation-Maximization (EM) algorithm. Finally, the expected number of mutations attributed by a signature, namely signature burden, is calculated for each tumor profiled by targeted sequencing.

The main functions in this package are GenerateVMatrix, GenerateLMatrix, ValidateSATSInputs,
EstimateSigActivity, CalculateSignatureBurdens, and MappingSignature.

The accompanying manuscript applies SATS to 111,711 tumors profiled by targeted sequencing from AACR Project GENIE to construct a real-world, panel-calibrated pan-cancer catalogue of mutational signatures.

Author(s)

Donghyuk Lee <dhyuklee@pusan.ac.kr> and Bin Zhu <bin.zhu@nih.gov>

References

Lee, D., Hua, M., Wang, D., Song, L., Yu, K., Yang, X., Shi, J., Landi, M., Zhu, B. A real-world pan-cancer catalogue of mutational signatures from 111,711 tumors. Submitted.


SATS documentation built on Sept. 16, 2026, 1:06 a.m.