| CalculateSignatureBurdens | R Documentation |
Estimation of the expected number of mutations attributed by TMB-based catalog signatures (signature burden) given the sample-level panel-context matrix, the catalog signature-profile matrix and the signature activities matrix.
CalculateSignatureBurdens(L, W, H)
L |
Sample-level panel-context matrix or data frame with samples in columns, see
|
W |
Catalog signature-profile matrix or data frame with signatures in columns |
H |
Activity matrix or data frame with samples in columns,
see |
The sample-level panel-context matrix L is of size P (the mutation
context) by N (the sample size). The catalog signature-profile matrix
W has dimension P by K (the number of signatures) and the activity
matrix H is of
size K by N. For single base substitutions (SBS), P is 96.
If K is the number of signatures and N is
the number of samples, then H must be of dimension K X N,
ncol(L) = N, and ncol(W) = K.
The input matrices must contain numeric, finite and non-negative values. When
row names and column names are present, CalculateSignatureBurdens()
checks that L, W and H contain matched mutation contexts,
signature names and sample IDs. If the same names are present in a different
order, L and W are reordered to match H. If one object has
names on an axis used for alignment and the paired object does not, or if the
named entries differ between matrices, the function stops with an informative
error. Users can run ValidateSATSInputs directly to check and
align inputs before calling this function.
For the catalog signature profile matrix W, reference SBS TMB
signature profiles in data(SimData) can be used.
A matrix of dimension K X N, where K is the number
of signatures and N is the number of samples.
Donghyuk Lee <dhyuklee@pusan.ac.kr> and Bin Zhu <bin.zhu@nih.gov>
EstimateSigActivity, ValidateSATSInputs
data(SimData, package="SATS")
CalculateSignatureBurdens(SimData$L, SimData$TrueW_TMB, SimData$TrueH)
# For more detailed usage, please refer to README and the user manual
# in https://github.com/binzhulab/SATS/tree/main.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.