View source: R/mappingSignature.R
| MappingSignature | R Documentation |
This function finds a subset of TMB-based catalog SBS signatures
whose linear combinations approximate
de novo SBS signatures detected by signeR.
MappingSignature(W_hat, W_ref=NULL, niter=100, cutoff.I2=0.1, min.repeats=80,
COSMICv="v3.4")
W_hat |
Matrix or data frame of de novo signatures from signeR |
W_ref |
NULL or a matrix or data frame of TMB-based catalog signatures.
If NULL, then it will default to |
niter |
Number of iterations. The default is 100. |
cutoff.I2 |
Coefficient cutoff used to select reference signatures.
The default is 0.1, requiring a retained reference
signature to contribute more than 10 percent to a
|
min.repeats |
Minimum number of repeated fits in which a reference
signature must satisfy |
COSMICv |
Version of the TMB-based COSMIC signatures ("v3.2" or "v3.4").
This option is ignored if |
MappingSignature() applies penalized non-negative least squares
(pNNLS) for selecting the TMB-based catalog signatures.
Specifically, it repeats pNNLS 100 times (niter) to reduce
the randomness of cross-validation involved in pNNLS.
Then TMB-based catalog signatures are selected with a coefficient
greater than cutoff.I2 in at least min.repeats repeats.
With the default settings, a retained signature must have a coefficient
greater than 0.1 in at least 80 of 100 repeated fits.
A data frame with one row per retained reference signature. The
Reference column contains the corresponding column names of W_ref
(COSMIC SBS names when the default COSMIC reference matrix is used), and
freq gives the number of repeated fits in which the signature coefficient
exceeded cutoff.I2.
Donghyuk Lee <dhyuklee@pusan.ac.kr> and Bin Zhu <bin.zhu@nih.gov>
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.